/*****************************************************************************
  CLASS:				MiscGaugeView
  INHERITS FROM:		Control
  PROGRAMMER:			Todd Thomas, Copyright 1995.
  DATE BEGAN:			March 10, 1995
  LAST CHANGED:			-
  VERSION:				0.1
  CHANGES:				-
  
  This class is basically a view that displays a MiscGaugeCell. Most all the
  methods just pass the message onto the gauge cell. 
  
  As for updating the cell, if just the hand is affected by a method call,
  Control's drawCellInside: method is used for a minimal update. On the 
  other hand, if the method called affects the gauge "face", View's update 
  is called so the cached "face" is redrawn. 
  
  See the MiscGaugeView class for more information, since that is where most
  of the work is done.

  This object is included in the MiscKit by permission from the author
  and its use is governed by the MiscKit license, found in the file
  "LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
  for a list of all applicable permissions and restrictions.  
 *****************************************************************************/

#import <AppKit/AppKit.h>


@interface MiscGaugeView : NSControl
{

}

+ (void)initialize;
+ (void)setCellClass: aClass;

- initWithFrame:(NSRect)frameRect;

- initFrame:(NSRect)frameRect min:(float)min max:(float)max startAngle:(float)start range:(float)range tickInterval:(int)interval;

- (float)maxValue;
- (float)minValue;

- (void)setMaxValue: (float)max;
- (void)setMinValue: (float)min;
 
- (float)startAngle;
- (float)angleRange;
- (int)tickInterval;
- (float)tickRatio;
- (float)handRatio;

- (void)setStartAngle:(float)newValue; 
- (void)setAngleRange:(float)newValue; 
- (void)setTickInterval:(int)newValue; 
- (void)setTickRatio:(float)newRatio;
- (void)setHandRatio:(float)newRatio;

//- (NXColor)backgroundColor;
- (NSColor *)gaugeColor;
- (NSColor *)textColor;
//- setBackgroundColor: (NXColor)color;
- (void)setGaugeColor:(NSColor *)color;
- (void)setTextColor: (NSColor *)color;

//- (float)backgroundGray;
- (float)gaugeGray;
- (float)textGray;
//- setBackgroundGray: (float)gray;
- (void)setGaugeGray:(float)gray;
- (void)setTextGray: (float)gray;

- titleFont;
- (void)setTitleFont: newFont;
- (NSString *)title;
- (void)setTitle:(NSString *)newTitle;
- (NSTitlePosition)titlePosition;
- (void)setTitlePosition: (NSTitlePosition)newPos;

@end

