/****************************************************************************
  CLASS:				MiscGaugeView
  
  See the interface file for more information on this class.

  This object is included in the MiscKit by permission from the author
  and its use is governed by the MiscKit license, found in the file
  "LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
  for a list of all applicable permissions and restrictions.
 ****************************************************************************/

//#import <AppKit/AppKit.h>
#import "MiscGaugeCell.h"
#import "MiscGaugeView.h"

// The cell our Control will display.
id  myCellClass;


@implementation MiscGaugeView 

+ (void)initialize
{
	if (self == [MiscGaugeView class])
		// By default use the MiscGaugeCell cell.
		myCellClass = [MiscGaugeCell class];
}


+ (void)setCellClass: aClass
{
	myCellClass = aClass;
}


- initWithFrame:(NSRect)frameRect
{
	// Basic initFrame method which just calls the more complicated 
	// initFrame:min:max... method with some generally good default values.
    [self initFrame:frameRect min:0.0 max:100.0 startAngle:215.0 range:250.0 tickInterval:10]; 
	return self;
}


- initFrame:(NSRect)frameRect min:(float)min max:(float)max startAngle:(float)start range:(float)range tickInterval:(int)interval
{
	if ([super initWithFrame:frameRect] == nil)
		return nil;
		
	// Set ourselves to use our gaugecell.
 	[self setCell: [ [ [myCellClass alloc] init] autorelease]];
//	[self setOpaque: NO];
		
	[self setStartAngle:start];
	[self setAngleRange:range];
	[self setTickInterval:interval];
	[self setMinValue: min];
	[self setMaxValue: max];
	[self setFloatValue: min];
	[self setTitleFont: [NSFont fontWithName:@"Helvetica" size:10] ];
	return self;
}


- (float)maxValue { return [ (MiscGaugeCell *)[self cell] maxValue]; }
- (float)minValue { return [ (MiscGaugeCell *)[self cell] minValue]; }


- (void)setMaxValue: (float)max 
{ 
	// Don't redraw if the new max is the same as the old.
	if (max != [ (MiscGaugeCell *)[self cell] maxValue])
	{
		[ (MiscGaugeCell *)[self cell] setMaxValue: max]; 
		[self setNeedsDisplay:YES];
	 }
}


- (void)setMinValue: (float)min 
{ 
	// Don't redraw if the new min is the same as the old.
	if (min != [ (MiscGaugeCell *)[self cell] maxValue])
	{
		[ (MiscGaugeCell *)[self cell] setMinValue: min]; 
		[self setNeedsDisplay:YES];
	}
}


- (float)startAngle { return [ [self cell] startAngle]; }
- (float)angleRange { return [ [self cell] angleRange]; }
- (int)tickInterval { return [ [self cell] tickInterval]; }
- (float)tickRatio { return [ [self cell] tickRatio]; }
- (float)handRatio { return [ [self cell] handRatio]; }


- (void)setStartAngle:(float)newValue
{
	if (newValue != [ [self cell] startAngle])
	{
		[[self cell] setStartAngle:newValue];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setAngleRange:(float)newValue
{
	if (newValue != [ [self cell] angleRange])
	{
		[[self cell] setAngleRange:newValue];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setTickInterval:(int)newValue
{
	if (newValue != [ [self cell] tickInterval])
	{
		[[self cell] setTickInterval:newValue];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setTickRatio:(float)newRatio
{
	if (newRatio != [ [self cell] tickRatio])
	{
		[[self cell] setTickRatio:newRatio];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setHandRatio:(float)newRatio
{
	[[self cell] setHandRatio:newRatio];
	[self updateCellInside: [self cell] ]; 
}


//- (NXColor)backgroundColor { return [ [self cell] backgroundColor]; }
- (NSColor *)gaugeColor { return [ [self cell] gaugeColor]; }
- (NSColor *)textColor { return [ [self cell] textColor]; }

/*
- (void)setBackgroundColor: (NXColor)color
{
	if (NXEqualColor (color, [self backgroundColor]) == NO)
	{
		[ [self cell] setBackgroundColor: color];
		[self update];
	 }
}
*/

- (void)setGaugeColor:(NSColor *)color
{
	if ([color isEqual:[self gaugeColor]] == NO)
	{
		[[self cell] setGaugeColor:color];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setTextColor: (NSColor *)color
{
	if ([color isEqual:[self textColor]] == NO)
	{
		[ [self cell] setTextColor: color];
		[self setNeedsDisplay:YES];
	 }
}


//- (float)backgroundGray	{ return [ [self cell] backgroundGray]; }
- (float)gaugeGray { return [ [self cell] gaugeGray]; }

- (float)textGray { return [[[[self cell] textColor] colorUsingColorSpaceName:NSCalibratedWhiteColorSpace] whiteComponent]; }

/*
- setBackgroundGray: (float)gray
{
	if (gray != [self backgroundGray])
	{
		[ [self cell] setBackgroundGray: gray];
		[self update];
	 }
	return self;
}
*/

- (void)setGaugeGray:(float)gray
{
	if (gray != [self gaugeGray])
	{
		[[self cell] setGaugeGray:gray];
		[self setNeedsDisplay:YES];
	 } 
}


- (void)setTextGray: (float)gray
{
	if (gray != [[[self textColor] colorUsingColorSpaceName:NSCalibratedWhiteColorSpace] whiteComponent])
	{
		[[self cell] setTextColor:[NSColor colorWithCalibratedWhite:gray alpha:1.0]];
		[self setNeedsDisplay:YES];
	 }
}


- titleFont { return [ [self cell] titleFont]; }
- (NSString *)title { return [[self cell] title]; }
- (NSTitlePosition)titlePosition { return [ [self cell] titlePosition]; }


- (void)setTitleFont: newFont
{
	[ [self cell] setTitleFont: newFont];
	[self setNeedsDisplay:YES];
}


- (void)setTitle:(NSString *)newTitle
{
	[[self cell] setTitle:newTitle];
	[self setNeedsDisplay:YES];
}


- (void)setTitlePosition: (NSTitlePosition)newPos
{
	// Valid positions are NX_ATTOP and NX_ATBOTTOM.
	if (newPos != [self titlePosition])
	{
		[ [self cell] setTitlePosition: newPos];
		[self setNeedsDisplay:YES];
	 }
}

@end

