//-----------------------------------------------------------------------------------------------------------------
//		Written by Uwe Hoffmann Copyright 1995 by Uwe Hoffmann.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//-----------------------------------------------------------------------------------------------------------------

#import "MiscObjectSkipList.h"
#import <Foundation/NSUtilities.h>
#import <Foundation/NSException.h>
#import <Foundation/NSCoder.h>

@implementation MiscObjectSkipList

- init
{
	self = [super init];
	compareSelector = @selector(compare:);
	compareWithSelector = YES;
	return self;
}

- initCompareSelector:(SEL)comparator
{
	self = [super init];
	compareSelector = comparator;
	compareWithSelector = YES;
	return self;
}

- initCompareFunction:(int(*)(id, id, void *))comparator context:(void *)context
{
	self = [super init];
	compareFunction = comparator;
	compareContext = context;
	compareWithSelector = NO;
	return self;
}

- initWithObjects:(id *)objects count:(unsigned)count
{
	unsigned i;
	
	self = [super init];
	compareSelector = @selector(compare:);
	compareWithSelector = YES;
	for(i = 0;i < count;i++)
		[self insertObject:objects[i]];
	return self;
}

- initWithObjects:(id *)objects count:(unsigned)count compareSelector:(SEL)comparator
{
	unsigned i;
	
	self = [super init];
	compareSelector = comparator;
	compareWithSelector = YES;
	for(i = 0;i < count;i++)
		[self insertObject:objects[i]];
	return self;
}

- initWithObjects:(id *)objects count:(unsigned)count compareFunction:(int(*)(id, id, void *))comparator context:(void *)context
{
	unsigned i;
	
	self = [super init];
	compareFunction = comparator;
	compareContext = context;
	compareWithSelector = NO;
	for(i = 0;i < count;i++)
		[self insertObject:objects[i]];
	return self;
}

- initWithCoder:(NSCoder *)coder
{
    self = [super initWithCoder:coder];
    //[coder decodeValuesOfObjCTypes:"", , ];
	[self insertObjectsFromArray:[coder decodeObject]];
    return self;
}

- (void)encodeWithCoder:(NSCoder *)coder
{
    [super encodeWithCoder:coder];
	//[coder encodeValuesOfObjCTypes:"", , ];
    [coder encodeObject:[self allObjects]];
}

- (NSComparisonResult)compareNode:(SkipListNode *)p withObject:anObject
{
	NSComparisonResult result;
	int (*test)(id, SEL, id);
	
	if(!p)
		return NSOrderedDescending;
	if(compareWithSelector){
		test = (int (*)(id, SEL, id))[anObject methodForSelector:compareSelector];
		result = test(p->nodeObject, compareSelector, anObject);
	} else
		result = compareFunction((NSObject *)p->nodeObject, anObject, compareContext);
	return result;
}	

- (void)checkArgument:anObject
{
	if(!anObject)
		[NSException raise:NSInvalidArgumentException format:@"Argument is nil"];
	return;
}

@end
