//-----------------------------------------------------------------------------------------------------------------
//		Written by Uwe Hoffmann Copyright 1995 by Uwe Hoffmann.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//-----------------------------------------------------------------------------------------------------------------

#import "MiscStringSkipList.h"
#import <Foundation/NSUtilities.h>
#import <Foundation/NSException.h>
#import <Foundation/NSCoder.h>

@implementation MiscStringSkipList

- init
{
	self = [super init];
	options = 0;
	range.location = 0;
	range.length = 0;
	compareMode = 1;
	return self;
}

- initOptions:(unsigned)mask
{
	self = [super init];
	options = mask;
	range.location = 0;
	range.length = 0;
	compareMode = 2;
	return self;
}

- initOptions:(unsigned)mask range:(NSRange)aRange
{
	self = [super init];
	options = mask;
	range = aRange;
	compareMode = 3;
	return self;
}

- initWithCoder:(NSCoder *)coder
{
    self = [super initWithCoder:coder];
    [coder decodeValuesOfObjCTypes:"i{ii}i", &options, &range, &compareMode];
	[self insertObjectsFromArray:[coder decodeObject]];
    return self;
}

- (void)encodeWithCoder:(NSCoder *)coder
{
    [super encodeWithCoder:coder];
	[coder encodeValuesOfObjCTypes:"i{ii}i", &options, &range, &compareMode];
    [coder encodeObject:[self allObjects]];
}

- (NSComparisonResult)compareNode:(SkipListNode *)p withObject:anObject
{
	NSComparisonResult result = NSOrderedDescending;
	
	if(!p)
		return NSOrderedDescending;
	switch(compareMode){
		case 1:
			result = [(NSString *)p->nodeObject compare:(NSString *)anObject];
			break;
		case 2:
			result = [(NSString *)p->nodeObject compare:(NSString *)anObject options:options];
			break;
		case 3:
			result = [(NSString *)p->nodeObject compare:(NSString *)anObject options:options range:range];
			break;
		default:
			break;
	}
	return result;
}	

- (void)checkArgument:anObject
{
	if(!anObject)
		[NSException raise:NSInvalidArgumentException format:@"Argument is nil"];
	if(![anObject isKindOfClass:[NSString class]])
		[NSException raise:NSInvalidArgumentException format:@"Argument is not a NSString"];
	return;
}

@end
