/*
		Copyright (c) Uwe Hoffmann, 1995.
                  All Rights Reserved.

Filename: MiscUndoManager.h
Author:   Uwe Hoffmann
Date:	  Jun 30, 1995

$Id: MiscUndoManager.h,v 1.0 1995/06/30 11:22:00 Uwe Hoffmann Exp $
 $Log: MiscUndoManager.h,v $
*/


#import <Foundation/Foundation.h>

@class MiscUndoGroup;
@class MiscUndoRecord;

@interface MiscUndoManager:NSObject
{
	NSMutableArray *undoArray;	/*"Holds the groups of undo records."*/
	NSMutableArray *redoArray;	/*"Holds the groups of redo records."*/
	int disabled;				/*"Whether MiscUndoManager accepts registrations."*/
	unsigned levelsOfUndo;		/*"Maximum number of undo groups in the undoArray."*/		
	MiscUndoGroup *currentGroup;	/*"The current group which isn't already commited."*/
	BOOL undoing;				/*"The "redo" state, if YES commited groups are added to redoArray."*/
	BOOL redoing;				/*"The "undo" state, if YES commited groups are added to undoArray."*/
}

/*"Starting and commiting record group"*/
- (void)startUndo:(NSString *)undoName :(NSString *)redoName;
- (void)commitUndo;

/*"Registering a undo record"*/ 
- (void)registerRecord:(MiscUndoRecord *)record;

/*"Methods for menu validation"*/
- (NSString *)undoName;
- (NSString *)redoName;
- (unsigned)numberOfUndos;
- (unsigned)numberOfRedos;

/*"Undo and redo"*/
- (void)undo;
- (void)redo;

/*"Enabling and disabling registration"*/
- (void)disableUndoRegistration;
- (void)reenableUndoRegistration;

/*"Setting and querying the levels of undo"*/
- (unsigned)levelsOfUndo;
- (void)setLevelsOfUndo:(unsigned)value;

/*"Emptying manager"*/ 
- (void)emptyManager;

@end


