/*
**	SwitchView.h 
**	Copyright (C) 1995  David Slotnick 
**	 
**	This program is free software; you can redistribute it and/or 
**	modify it under the terms of the GNU General Public License as 
**	published by the Free Software Foundation; either version 1, or 
**	(at your option) any later version. 
**	 
**	This program is distributed in the hope that it will be useful, 
**	but WITHOUT ANY WARRANTY; without even the implied warranty of 
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
**	GNU General Public License for more details. 
**	 
**	You should have received a copy of the GNU General Public License 
**	along with this program; if not, write to the Free Software 
**	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
*/

/***************************************************************************/
// Included Files
//
#import <appkit/appkit.h>
#import <foundation/foundation.h>

/***************************************************************************/
// Constants
//
#define SV_NO_VISIBLE_VIEW -1;

/***************************************************************************/
// Interface
//
@interface SwitchView:Box
{
	NSMutableArray 		*views;			// managed views
	id					delegate;		// receives notifications
}

- initFrame:(const NXRect *)frameRect;
- free;

- delegate;
- setDelegate:anObj;

- (void) addView;
- (void) insertViewAtIndex:(int)index; 
- (void) displayViewAtIndex:(int)index;
- (void) deleteViewAtIndex:(int)index;

- (int) lastIndex;
- (int) firstIndex;
- (View *) viewAtIndex:(int)index;
- (int) indexBefore:(int)index;
- (int) indexAfter:(int)index;
- (int) viewCount;
- (int) indexOfVisibleView;
- (BOOL) isIndexValid:(int)index;

- takeIntValueFrom:sender;
- takeStringValueFrom:sender;
- takeFloatValueFrom:sender;
- takeDoubleValueFrom:sender;
- takeTagValueFrom:sender;
- takeSelectedTagValueFrom:sender;

- awake;
- read:(NXTypedStream *)stream;
- write:(NXTypedStream *)stream;

@end

@protocol SwitchViewDelegates
- (BOOL) switchView:(SwitchView *)sender willInsertViewAtIndex:(int)index;
- (void) switchView:(SwitchView *)sender didInsertViewAtIndex:(int)index;
	
- (BOOL) switchView:(SwitchView *)sender willDeleteViewAtIndex:(int)index;
- (void) switchView:(SwitchView *)sender didDeleteViewAtIndex:(int)index;
	
- (BOOL) switchView:(SwitchView *)sender willDisplayViewAtIndex:(int)index;
- (void) switchView:(SwitchView *)sender didDisplayViewAtIndex:(int)index;

- (BOOL) switchViewWillAddView:(SwitchView *)sender;
- (void) switchViewDidAddView:(SwitchView *)sender;
@end
