/*
**	SwitchViewInspector.m 
**	Copyright (C) 1995  David Slotnick 
**	 
**	This program is free software; you can redistribute it and/or 
**	modify it under the terms of the GNU General Public License as 
**	published by the Free Software Foundation; either version 1, or 
**	(at your option) any later version. 
**	 
**	This program is distributed in the hope that it will be useful, 
**	but WITHOUT ANY WARRANTY; without even the implied warranty of 
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
**	GNU General Public License for more details. 
**	 
**	You should have received a copy of the GNU General Public License 
**	along with this program; if not, write to the Free Software 
**	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
*/

/***************************************************************************/
// RCS identification information
//
static char rcsID[] = "$Id: SwitchViewInspector.m,v 1.2 1995/03/18 20:36:22 davids Exp $";
static void __AvoidCompilerWarning(void) {if(!rcsID)__AvoidCompilerWarning();}

/***************************************************************************/
// Included Files
//
#import "SwitchViewInspector.h"
#import "SwitchView.h"

/***************************************************************************/
// Public Methods
//
@implementation SwitchViewInspector 

/*
**	Loads the SwitchViewInspector nib file. 
*/
- init
{
	NSString	*path;
	NSBundle	*bundle;
	BOOL		error = NO;
		
	[super init];
	
	bundle = [NSBundle bundleForClass:[SwitchView class]];
	path = [bundle pathForResource:@"SwitchViewInspector" ofType:@"nib"];
	if (![NXApp loadNibFile:[path cString] 
			owner:self 
			withNames:NO 
			fromZone:[self zone]]) {
		[NSException raise:NSGenericException 
			format:@"-[SwitchViewInspector init]:: could not load %@", path];
		error = YES;
	}
	
	return error ? nil : self;
}

/*
**	Adds an empty View add the end of the SwitchView's View list. 
*/
- addView:sender
{
	// add a View to the SwitchView
	[object addView];
	
	// revert thyself 
	[self revert:sender];

	return self;
}

/*
**	Inserts an empty View at the index specified in currentView 
**	TextField (on the inspector panel). 
*/
- insertView:sender
{
	int newIndex = [currentViewTF intValue];

	// only proceed if the index is valid
	if ([object isIndexValid:newIndex]) {
		[object insertViewAtIndex:newIndex];
		[object displayViewAtIndex:newIndex];
	} else {
		NXBeep ();
	}
	
	// revert thyself 
	[self revert:sender];

	return self;
}

/*
**	Deletes the View at the index specified in the currentView 
**	TextField (on the inspector panel). 
*/
- deleteView:sender
{
	int newIndex = [currentViewTF intValue];
	
	// only proceed if the index is valid
	if ([object isIndexValid:newIndex]) {
		[object deleteViewAtIndex:newIndex];
		[object displayViewAtIndex:MIN (newIndex,[object lastIndex])];
	} else {
		NXBeep ();
	}
	
	// revert thyself 
	[self revert:sender];

	return self;
}

/*
**	Displays the View at the index specified in the currentView 
**	TextField (on the inspector panel). 
*/
- setCurrentView:sender
{
	int newIndex = [sender intValue];

	// only proceed if the index is valid
	if ([object isIndexValid:newIndex]) {
		[object displayViewAtIndex:newIndex];
	} else {
		NXBeep ();
	}

	// revert thyself 
	[self revert:sender];
	
	return self;
}

/*
**	Displays the View after the currently displayed View, or the 
**	first View if the last View is currently displayed. 
*/
- nextView:sender
{
	int nextIndex = [object indexAfter:[object indexOfVisibleView]];
	[object displayViewAtIndex:nextIndex];
	[self revert:sender];
	return self;
}

/*
**	Displays the View before the currently displayed View, or the 
**	last View if the first View is currently displayed. 
*/
- previousView:sender
{
	int previousIndex = [object indexBefore:[object indexOfVisibleView]];
	[object displayViewAtIndex:previousIndex];
	[self revert:sender];
	return self;
}
	
/*
**	Causes the inspector to display the attributes of the 
**	currently inspected SwitchView. 
*/
- revert:sender
{
	[[viewCountTF setIntValue:[object viewCount]] display];
	[[currentViewTF setIntValue:[object indexOfVisibleView]] display];
	[[NXApp activeDocument] redrawObject:object];
	return [super revert:sender];
}

/*
**	All the controls in the inspector window take affect immediately, 
**	so these aren't needed. 
*/
- ok:sender { return [super ok:sender]; }
- (BOOL)wantsButtons { return NO; }

@end
