
#import "AppController.h"
#import "MiscSortedCollection.h"
#import "ScrollViewExtensions.h"
#import "TestObject.h"
#import <foundation/foundation.h>
#import <foundation/NSArchiver.h>

static const char *opSeparator = "\n----------------------------------------------------------------------\n";
@implementation AppController

- appDidInit:sender
{
	numberSkipList = [[MiscMutableSortedCollection numberCollection] retain];
	stringSkipList = [[MiscMutableSortedCollection stringCollection] retain];
	objectSkipList = [[MiscMutableSortedCollection collection] retain];
	[window makeKeyAndOrderFront:nil];
	return self;
}
				
- (void)delete
{
	id object;
	
	if([radio selectedTag] == 1){
		object = [NSString stringWithCString:[(Cell *)valueField stringValue]];
		[stringSkipList removeAllObjectsOrderedSameAs:object];
		[scrollView printString:[(MiscSortedCollection *)stringSkipList description]];
	} else if([radio selectedTag] == 0){
		object = [NSNumber numberWithFloat:[(Cell *)valueField floatValue]];
		[numberSkipList removeAllObjectsOrderedSameAs:object];
		[scrollView printString:[(MiscSortedCollection *)numberSkipList description]];
	} else {
		object = [TestObject objectWithCString:[(Cell *)valueField stringValue]];
		[objectSkipList removeAllObjectsOrderedSameAs:object];
		[scrollView printString:[(MiscSortedCollection *)objectSkipList description]];
	}
    return;
}

- (void)insert
{
	id object;
	
	if([radio selectedTag] == 1){
		object = [NSString stringWithCString:[(Cell *)valueField stringValue]];
		[stringSkipList insertObject:object];
		[scrollView printString:[(MiscSortedCollection *)stringSkipList description]];
	} else if([radio selectedTag] == 0){
		object = [NSNumber numberWithFloat:[(Cell *)valueField floatValue]];
		[numberSkipList insertObject:object];
		[scrollView printString:[(MiscSortedCollection *)numberSkipList description]];
	} else {
		object = [TestObject objectWithCString:[(Cell *)valueField stringValue]];
		[objectSkipList insertObject:object];
		[scrollView printString:[(MiscSortedCollection *)objectSkipList description]];
	}
    return;
}

- (void)before
{
	id object, result;
	
	if([radio selectedTag] == 1){
		object = [NSString stringWithCString:[(Cell *)valueField stringValue]];
		result = [stringSkipList objectBefore:object];
	} else if([radio selectedTag] == 0){
		object = [NSNumber numberWithFloat:[(Cell *)valueField floatValue]];
		result = [numberSkipList objectBefore:object];
	} else {
		object = [TestObject objectWithCString:[(Cell *)valueField stringValue]];
		result = [objectSkipList objectBefore:object];
	}
	if(result)
		[scrollView printString:[(NSObject *)result description]];
	else
		[scrollView printString:@"Nil object"];
	return;
}

- (void)same
{
	id object, resultArray;
	
	if([radio selectedTag] == 1){
		object = [NSString stringWithCString:[(Cell *)valueField stringValue]];
		resultArray = [stringSkipList allObjectsOrderedSameAs:object];
	} else if([radio selectedTag] == 0){
		object = [NSNumber numberWithFloat:[(Cell *)valueField floatValue]];
		resultArray = [numberSkipList allObjectsOrderedSameAs:object];
	} else {
		object = [TestObject objectWithCString:[(Cell *)valueField stringValue]];
		resultArray = [objectSkipList allObjectsOrderedSameAs:object];
	}
	[scrollView printString:[(NSArray *)resultArray description]];
	return;
}

- removeAll:sender
{	
	[scrollView sprintf:opSeparator];
	if([radio selectedTag] == 1){
		[stringSkipList removeAllObjects];
		[scrollView printString:[(MiscSortedCollection *)stringSkipList description]];
	} else if([radio selectedTag] == 0){
		[numberSkipList removeAllObjects];
		[scrollView printString:[(MiscSortedCollection *)numberSkipList description]];
	} else {
		[objectSkipList removeAllObjects];
		[scrollView printString:[(MiscSortedCollection *)objectSkipList description]];
	}
    return self;
}

- showSkipList:sender
{
	[scrollView sprintf:opSeparator];
	if([radio selectedTag] == 1){
		[scrollView printString:[(MiscSortedCollection *)stringSkipList description]];
	} else if([radio selectedTag] == 0){
		[scrollView printString:[(MiscSortedCollection *)numberSkipList description]];
	} else {
		[scrollView printString:[(MiscSortedCollection *)objectSkipList description]];
	}
    return self;
}

- load:sender
{
    const char *const *files;
	const char *directory;
	NSString *path;
	id unarchivedObject;
  	const char *const allowedType[2] = {"skiplist", NULL};
    id openpanel = [[OpenPanel new] allowMultipleFiles:NO];

    if([openpanel runModalForTypes:allowedType]){
		files = [openpanel filenames];
		directory = [openpanel directory];
		if(files && *files){
			path = [NSString stringWithFormat:@"%s/%s",directory,*files];
			unarchivedObject = [NSUnarchiver unarchiveObjectWithFile:path];
			[scrollView sprintf:opSeparator];
			if(unarchivedObject && [[unarchivedObject smallest] isKindOf:[NSString class]]){
				[stringSkipList release];
				stringSkipList = [unarchivedObject retain];
				[scrollView sprintf:"Succesfully unarchived a String skiplist\n"];	
			} else if(unarchivedObject && [[unarchivedObject smallest] isKindOf:[NSNumber class]]){
				[numberSkipList release];
				numberSkipList = [unarchivedObject retain];
				[scrollView sprintf:"Succesfully unarchived a Number skiplist\n"];
			} else if(unarchivedObject && [[unarchivedObject smallest] isKindOf:[TestObject class]]){
				[objectSkipList release];
				objectSkipList = [unarchivedObject retain];
				[scrollView sprintf:"Succesfully unarchived a Object skiplist\n"];
			} else
				[scrollView sprintf:"Unarchiving not succesful\n"]; 
		}
    }
    return self;
}

- save:sender
{
    id savepanel;	
	NSString *path;
	BOOL result;
	
    savepanel = [SavePanel new];
	[savepanel setRequiredFileType:"skiplist"];
	if([savepanel runModal]){ 
		path = [NSString stringWithCString:[savepanel filename]];
		if([radio selectedTag] == 1)
			result = [NSArchiver archiveRootObject:stringSkipList toFile:path];
		else if([radio selectedTag] == 0)
			result = [NSArchiver archiveRootObject:numberSkipList toFile:path];
		else
			result = [NSArchiver archiveRootObject:objectSkipList toFile:path];
		[scrollView sprintf:opSeparator];
		if(result)
			[scrollView sprintf:"Archiving succesful\n"];
		else
			[scrollView sprintf:"Archiving not succesful\n"];		
    }
	return self;
}

- clear:sender
{
	[scrollView clear:self];
	return self;
}

- performOp:sender
{
	[scrollView sprintf:opSeparator];
	switch([opRadio selectedTag]){
		case 0:
				[self insert];
				break;
		case 1:
				[self delete];
				break;
		case 2:
				[self before];
				break;
		case 3:
				[self same];
				break;
		default:
				break;
	}		
	[valueField selectText:self];
	return self;
}

@end
