
#import "AppDelegate.h"
#import "MiscUndoRecord.h"

@implementation AppDelegate

- init
{
	[super init];
	undoManager = [[MiscUndoManager alloc] init];
	testValue = 0;
	return self;
}

- dec:sender
{	
	// start a new group 
	[undoManager startUndo:@"Undo Dec" :@"Redo Inc"];
	
	// register an undo-record
	// normally we would do this:
	//[undoManager registerRecord:[MiscUndoRecord recordWithInvocation:NS_MESSAGE(self, inc:sender)]];
	
	// without the official openstep headers we do this:
	[undoManager registerRecord:[MiscUndoRecord recordWithTarget:self 
		selector:@selector(inc:),sender]];
	
	// commit group (group consists only of this record)
	[undoManager commitUndo];
	
	// do the actual action
	testValue--;
	[textField setIntValue:testValue];
	[textField display];
    return self;
}

- inc:sender
{	
	// start a new group 
	[undoManager startUndo:@"Undo Inc" :@"Redo Dec"];
	
	// register an undo-record
	// [undoManager registerRecord:[MiscUndoRecord recordWithInvocation:NS_MESSAGE(self, dec:sender)]];
	
	// without the official openstep headers we do this:
	[undoManager registerRecord:[MiscUndoRecord recordWithTarget:self 
		selector:@selector(dec:),sender]];
	
	// commit group (group consists only of this record)
	[undoManager commitUndo];
	
	// do the actual action
	testValue++;
	[textField setIntValue:testValue];
	[textField display];
    return self;
}

- redo:sender
{
	[undoManager redo];
    return self;
}

- undo:sender
{
	[undoManager undo];
    return self;
}

- (BOOL)validateCommand:menuCell
{
    SEL action = [menuCell action];
	BOOL redraw = NO, wasEnabled = [menuCell isEnabled];
	
    if(action == @selector(undo:)){
		// disable if theres nothing to undo
		// set undo name
		// do all this by querying the undoManager
		if([undoManager numberOfUndos] == 0){
			[menuCell setEnabled:NO];
			if(wasEnabled)
				redraw = YES;
		} else {
			if(strcmp([menuCell title], [[undoManager undoName] cString]) != 0){
				[menuCell setTitle:[[undoManager undoName] cString]];
				redraw = YES;
			}
			[menuCell setEnabled:YES];
			if(!wasEnabled)
				redraw = YES;
		}
	} else if(action == @selector(redo:)){
	 	// disable if theres nothing to redo
		// set redo name
		// do all this by querying the undoManager
		if([undoManager numberOfRedos] == 0){
			[menuCell setEnabled:NO];
			if(wasEnabled)
				redraw = YES;
		} else {
			if(strcmp([menuCell title], [[undoManager redoName] cString]) != 0){
				[menuCell setTitle:[[undoManager redoName] cString]];
				redraw = YES;
			}
			[menuCell setEnabled:YES];
			if(!wasEnabled)
				redraw = YES;
		}
	}
    return redraw;
}

- (void)setupMenuUpdateActionFor:(Menu *)menu
/*
 * Diese Methode luft den gesamten Menbaum ab und trgt bei allen Menpunkten die Updateaction
 * *menuItemUpdate* ein. Der ACADEMYController implementiert eine entsprechende Methode, die einen
 * automatischen Mechanismus fr das Enableing/Disabling von Menpunkten zur Verfgung stellt.
 */
{
    MenuCell 	*menuCell;
	Matrix		*matrix;
    int 		count;

	/* Schleife ber alle Menupunkte im Men */
	matrix = [menu itemList];
    count = [matrix cellCount];
    while( count-- )
	{
		menuCell = [matrix cellAt:count :0];
		if ( [menuCell hasSubmenu] )
		{
			/* bei einem Untermen rekursiv dort die Updateaction eintragen */
			[self setupMenuUpdateActionFor:[menuCell target]];
		}
		else
		{
			/* sonst menuItemUpdate als Updateaction eintragen */
			[menuCell setUpdateAction:@selector(menuItemUpdate:) forMenu:menu];
		}
    }
}

- (BOOL)menuItemUpdate:(MenuCell *)menuCell
/*
 * Die Methode ist die Update-Action fr alle Menpunkte. Die Methode *setupMenuUpdateActionFor:*
 * trgt die Update-Action bei allen Menpunkten ein. In der Methode wird zunchst geprft, ob
 * es ein Objekt gibt, das die Action-Methode des Menpunktes empfngt. Dies kann ein direktes
 * target sein oder eine Objekt in der Responder-Chain. Ist kein Empfangsobjekt vorhanden, so
 * ist der Menpunkt auf jeden Fall nicht verfgbar. Wenn ein Empfangsobjekt vorhanden ist, wird
 * eine validateCommand-Nachricht zusammengebaut. Dazu wird den Methodennamen der Action-Methode
 * der String validateCommand vorangestellt. Aus "showGrid:" wird also "validateCommandShowGrid:".
 * Es wird geprft, ob das Empfangsobjekt auf die Methode antwortet. Wenn nicht ist der 
 * Menpunkt auf jeden Fall verfgbar. Wenn das Empfangsobjekt die Methode versteht wird die
 * Methode verschickt. Als Parameter wird ein NSMutableString mitgegeben, der den aktuellen Titel
 * des Menpunktes enthlt. Das Objekt kann mit *setString:* einen neuen Titel setzen und im
 * Rckgabewert den Status des Menpunktes setzen. Entsprechend wird die MenuCell des Menpunktes
 * verndert. Die validateCommand-Methode wird mit perform:withObject: verschickt. Damit es keine
 * Probleme mit dem Rckgabewert gibt sollte dieser als int deklariert werden.
 */
{
	NSString		*selName;
	NSString		*validateMsg;
	char			firstChar;
	SEL				action;
	SEL				validateSel;
	NSMutableString	*title;
	BOOL			enabled;
	id				target;
	
	/* Ziel der Nachricht, die Nachricht und den Status bestimmen */
	target = [menuCell target];
	action = [menuCell action];
	enabled = [menuCell isEnabled];
	if ( target == nil )
	{
		/* bei einer Nachricht an den FirstResponder das tatschliche Ziel bestimmen */
		target = [NXApp calcTargetForAction:action];
	}
	
	/* gibt es ein Objekt, das die Nachricht empfngt */
	if ( target != nil )
	{
		/* den Selector "validateCommand..." zusammenbauen */
		selName = NSStringFromSelector( action );
		if ( selName != nil )
		{
			firstChar = NXToUpper( *[selName cString] );
			validateMsg = [NSString stringWithFormat:@"validateCommand%@%@",
									[NSString stringWithCString:&firstChar length:1],
									[selName substringFromIndex:1]];
			validateSel = NSSelectorFromString( validateMsg );
			if ( validateSel != 0 )
			{
				/* die Methoden an das target schicken */
				if ( [target respondsTo:validateSel] )
				{
					title = [NSMutableString stringWithCString:[menuCell title]];
					enabled = (int)[target perform:validateSel withObject:title];
					
					/* hat das target den Titel (und den Status) gendert? */
					if ( strcmp( [menuCell title], [title cString] ) != 0 )
					{
						[menuCell setTitle:[title cString]];
						[menuCell setEnabled:enabled];
						return YES;
					}
					
					/* hat das target den Status gendert? */
					else if ( enabled != [menuCell isEnabled] )
					{
						[menuCell setEnabled:enabled];
						return YES;
					}
					
					/* keine nderung durch das target */
					return NO; 
				}
			}
		}
		
		/* wenn das target ein validat-Nachricht empfngt, aber das Ziel vorhanden ist, ist der
		   Menpunkt verfgbar */
		if ( ![menuCell isEnabled] )
		{
			[menuCell setEnabled:YES];
			return YES;
		}
	}
	else
	{
		/* kein Ziel also ist das Kommando nicht verfgbar */
		if ( [menuCell isEnabled] )
		{
			[menuCell setEnabled:NO];
			return YES;
		}
	}
	
	/* melden, da die Cell nicht ausgegeben werden mu */
	return NO;
}

- appDidInit:sender
{
	[self setupMenuUpdateActionFor:[NXApp mainMenu]];
	[NXApp setAutoupdate:YES];
	[[NXApp mainMenu] setAutoupdate:YES];
    return self;
}

- (BOOL)validateCommandRedo:(NSMutableString *)title
{
	if([undoManager numberOfRedos] == 0)
		return NO;
	else {
		if(! [title isEqual:[undoManager redoName]])
			[title setString:[undoManager redoName]];
		return YES;
	}
}

	
- (BOOL)validateCommandUndo:(NSMutableString *)title;
{
	if([undoManager numberOfUndos] == 0)
		return NO;
	else {
		if(! [title isEqual:[undoManager undoName]])
			[title setString:[undoManager undoName]];
		return YES;
	}
}

@end
